# Confirmation AEA AW3

An agent that purchases information from other agents as specified in its configuration. It acts as the confirmation AEA in Agent World 3.

## Description

This agent uses the `fetchai/confirmation_aw3` skill to purchase data from valid Agent World 3 participants.

## Links
